import { OutputArea, OutputAreaModel } from '@jupyterlab/outputarea';
import { RenderMimeRegistry, standardRendererFactories } from '@jupyterlab/rendermime';
import { rendererFactory as jsonRendererFactory } from '@jupyterlab/json-extension';
import { rendererFactory as javascriptRendererFactory } from '@jupyterlab/javascript-extension';
export class OutputAdapter {
    _renderers;
    _outputArea;
    _rendermime;
    constructor(outputs) {
        this._renderers = standardRendererFactories.filter(factory => factory.mimeTypes[0] !== 'text/javascript');
        this._renderers.push(jsonRendererFactory);
        this._renderers.push(javascriptRendererFactory);
        this._rendermime = new RenderMimeRegistry({
            initialFactories: this._renderers,
        });
        const outputAreaModel = new OutputAreaModel({
            trusted: true,
            values: outputs,
        });
        this._outputArea = new OutputArea({
            model: outputAreaModel,
            rendermime: this._rendermime,
        });
    }
    clearOutput() {
        this._outputArea.model.clear();
    }
    get outputArea() {
        return this._outputArea;
    }
}
export default OutputAdapter;
//# sourceMappingURL=OutputAdapter.js.map