import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { ToolbarButton, ReactWidget } from '@jupyterlab/apputils';
import { ABCWidgetFactory, DocumentWidget } from '@jupyterlab/docregistry';
import { Token } from '@lumino/coreutils';
import { Signal } from '@lumino/signaling';
import DashboardWidget from './dashboardWidget';
export const IDashboardTracker = new Token('@datalayer/jupyter-react:IDashboardTracker');
export const DASHBOARD_ICON_CLASS = 'jp-MaterialIcon jp-NotebookIcon';
export class Dashboard extends DocumentWidget {
    _renderOnSave;
    constructor(options) {
        super({
            ...options,
            content: new DashboardWidget(options.context),
        });
        const { context, renderOnSave } = options;
        this.content.title.iconClass = DASHBOARD_ICON_CLASS;
        this.renderOnSave = renderOnSave ? true : false;
        context.pathChanged.connect(() => {
            //      this.content.url = getClassicUrl(context.path);
        });
        const reloadButton = new ToolbarButton({
            iconClass: 'jp-RefreshIcon',
            tooltip: 'Reload Dashboard',
            onClick: () => {
                this.reload();
            }
        });
        const renderOnSaveCheckbox = ReactWidget.create(_jsxs("label", { className: "jp-Preview-renderOnSave", children: [_jsx("input", { style: { verticalAlign: 'middle' }, name: "renderOnSave", type: "checkbox", defaultChecked: renderOnSave, onChange: (event) => {
                        this._renderOnSave = event.target.checked;
                    } }), "Render on Save"] }));
        this.toolbar.addItem('reload', reloadButton);
        if (context) {
            this.toolbar.addItem('renderOnSave', renderOnSaveCheckbox);
            void context.ready.then(() => {
                context.fileChanged.connect(() => {
                    if (this.renderOnSave) {
                        this.reload();
                    }
                });
            });
        }
    }
    dispose() {
        if (this.isDisposed) {
            return;
        }
        super.dispose();
        Signal.clearData(this);
    }
    reload() {
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        const iframe = this.content.node.querySelector('iframe');
        if (iframe.contentWindow) {
            iframe.contentWindow.location.reload();
        }
    }
    get renderOnSave() {
        return this._renderOnSave;
    }
    set renderOnSave(renderOnSave) {
        this._renderOnSave = renderOnSave;
    }
}
export class DashboardFactory extends ABCWidgetFactory {
    defaultRenderOnSave = false;
    constructor(options) {
        super(options);
    }
    createNewWidget(context) {
        return new Dashboard({
            context,
            renderOnSave: this.defaultRenderOnSave
        });
    }
}
//# sourceMappingURL=dashboard.js.map