import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { DisposableDelegate } from '@lumino/disposable';
import { ReactWidget } from '@jupyterlab/apputils';
import { ThemeProvider, BaseStyles, IconButton, Box } from '@primer/react';
import { JupyterBaseIcon as JupyterClassicRenderIcon, DashboardIcon as DashboardIcon } from '@datalayer/icons-react';
import { CLASSIC_RENDER_WIDGET_FACTORY } from './../classic/plugin';
import { DASHBOARD_WIDGET_FACTORY } from './../dashboard/plugin';
class NotebookHeader extends ReactWidget {
    _panel;
    _commands;
    constructor(panel, commands) {
        super();
        this._panel = panel;
        this._commands = commands;
    }
    renderClassic() {
        this._commands.execute('docmanager:open', {
            path: this._panel.context.path,
            factory: CLASSIC_RENDER_WIDGET_FACTORY,
            options: {
                mode: 'split-right'
            }
        });
    }
    showDashboard() {
        this._commands.execute('docmanager:open', {
            path: this._panel.context.path,
            factory: DASHBOARD_WIDGET_FACTORY,
            options: {
                mode: 'split-right'
            }
        });
    }
    render() {
        return (_jsx(ThemeProvider, { children: _jsx(BaseStyles, { children: _jsxs(Box, { m: 3, children: [_jsx(IconButton, { "aria-label": "Classic Render", icon: () => _jsx(JupyterClassicRenderIcon, { colored: true }), size: "medium", title: "Render the classic way", onClick: e => { e.preventDefault(); this.renderClassic(); } }), _jsx(IconButton, { "aria-label": "Edit as a Dashboard", icon: () => _jsx(DashboardIcon, { colored: true }), size: "medium", title: "Edit as a Dashboard", onClick: e => { e.preventDefault(); this.showDashboard(); }, sx: { ml: 3 } })] }) }) }));
    }
}
export class NotebookHeaderExtension {
    _commands;
    constructor(commands) {
        this._commands = commands;
    }
    createNew(panel, _) {
        const notebookHeader = new NotebookHeader(panel, this._commands);
        notebookHeader.addClass('dla-NotebookPanel-header');
        panel.contentHeader.insertWidget(0, notebookHeader);
        return new DisposableDelegate(() => {
            notebookHeader.dispose();
        });
    }
}
//# sourceMappingURL=NotebookHeader.js.map